"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchQueryBuilderOperatorEqualPlugin = void 0;
var _ElasticsearchQueryBuilderOperatorPlugin = require("../definition/ElasticsearchQueryBuilderOperatorPlugin");
class ElasticsearchQueryBuilderOperatorEqualPlugin extends _ElasticsearchQueryBuilderOperatorPlugin.ElasticsearchQueryBuilderOperatorPlugin {
  name = "elasticsearch.queryBuilder.operator.equal.default";
  getOperator() {
    return "eq";
  }
  apply(query, params) {
    const {
      value,
      path,
      basePath
    } = params;
    if (value === null) {
      query.must_not.push({
        exists: {
          field: path
        }
      });
      return;
    }
    const typeOf = typeof value;
    /**
     * If value is a number or boolean, use filtering instead of must/term
     */
    if (typeOf === "number" || typeOf === "boolean") {
      query.filter.push({
        term: {
          [basePath]: value
        }
      });
      return;
    }
    /**
     * In case we are searching for a string, use regular path.
     * Otherwise use base path.
     */
    const useBasePath = typeOf !== "string";
    const valuePath = useBasePath ? basePath : path;
    /**
     * String or something else.
     */
    query.filter.push({
      term: {
        [valuePath]: value
      }
    });
  }
}
exports.ElasticsearchQueryBuilderOperatorEqualPlugin = ElasticsearchQueryBuilderOperatorEqualPlugin;

//# sourceMappingURL=equal.js.map