"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSort = void 0;
var _error = _interopRequireDefault(require("@webiny/error"));
var _plugins = require("./plugins");
const sortRegExp = new RegExp(/^([a-zA-Z-0-9_@]+)_(ASC|DESC)$/);
const createSort = params => {
  const {
    sort,
    defaults,
    fieldPlugins
  } = params;
  if (!sort || sort.length === 0) {
    const {
      field,
      order,
      unmappedType
    } = defaults || {};
    /**
     * We say that our system defaults is always id since all records we create have some kind of primary ID.
     */
    return {
      [field || "id.keyword"]: {
        order: order || "desc",
        unmapped_type: unmappedType || undefined
      }
    };
  }
  /**
   * Cast as string because nothing else should be allowed yet.
   */
  return sort.reduce((acc, value) => {
    if (typeof value !== "string") {
      throw new _error.default(`Sort as object is not supported..`);
    }
    const match = value.match(sortRegExp);
    if (!match) {
      throw new _error.default(`Cannot sort by "${value}".`);
    }
    const [, field, initialOrder] = match;
    const order = initialOrder.toLowerCase() === "asc" ? "asc" : "desc";
    const plugin = fieldPlugins[field] || fieldPlugins[_plugins.ElasticsearchFieldPlugin.ALL];
    if (!plugin) {
      throw new _error.default(`Missing plugin for the field "${field}"`, "PLUGIN_SORT_ERROR", {
        field
      });
    }
    /**
     * In case field plugin is the global one, change the * with actual field name.
     * Custom path methods will return their own values anyway so replacing * will not matter.
     */
    const path = plugin.getPath(field);
    acc[path] = plugin.getSortOptions(order);
    return acc;
  }, {});
};
exports.createSort = createSort;

//# sourceMappingURL=sort.js.map